@@ -2,6 +2,23 @@ import time
 import paramiko
 
 
+def ssh_connect(hostname: str, username: str, password: str) -> paramiko.SSHClient:
+    """return connected ssh
+
+    Args:
+        hostname (str): address of host
+        username (str): username to login
+        password (str): password to login
+
+    Returns:
+        ssh (paramiko.SSHClient): connected ssh client
+    """
+    ssh = paramiko.SSHClient()
+    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+    ssh.connect(hostname=hostname, port=22, username=username, password=password)
+    return ssh
+
+
 def command(ssh: paramiko.SSHClient, query: str, timeout = None):
     """execute shell command
 
@@ -15,16 +32,23 @@ def command(ssh: paramiko.SSHClient, query: str, timeout = None):
     
     stdin, stdout, stderr = ssh.exec_command(query, timeout=timeout)
     
-    # Wait for the command to terminate
+    if timeout:
+        start_time = time.time()
+    # Wait for the command to terminate  
     while not stdout.channel.exit_status_ready():
         time.sleep(1)
+        if timeout:
+            latest_time = time.time()
+
+            if latest_time - start_time > timeout:
+                raise TimeoutError
     
     stdout_text = stdout.read().decode('utf-8').strip()
     err_text = stderr.read().decode('utf-8').strip()
     return stdout_text, err_text
 
 
-def execute_sql_query(ssh: paramiko.SSHClient, user_id: str, user_pw: str, db_name: str, query: str) -> str:
+def execute_sql_query(ssh: paramiko.SSHClient, user_id: str, user_pw: str, db_name: str, query: str):
     """execute sql query
 
     Args:
@@ -35,7 +59,7 @@ def execute_sql_query(ssh: paramiko.SSHClient, user_id: str, user_pw: str, db_na
         query (str): query statement to execute.
 
     Returns:
-        str: standard output of execution.
+        tuple[str, str]: stdout, stderr
     """    
     query = query.replace('\'','\"')
     fquery = f"""mysql -u{user_id} -p{user_pw} {db_name} -e '{query}'"""
