@@ -319,7 +319,7 @@ def line_login(driver: WebDriver, line_email, line_passwd):
             return False
 
     if driver.find_elements(By.CSS_SELECTOR, 'button.c-button.l-btn.c-button--allow'):
-        driver.find_element(By.CSS_SELECTOR, 'button.c-button.l-btn.c-button--allow').click()
+        driver.find_elements(By.CSS_SELECTOR, 'button.c-button.l-btn.c-button--allow')[0].click()
     
     time.sleep(.5)
 
@@ -389,15 +389,3 @@ def solve_reCAPTCHA(driver):
     result_flag = driver.execute_script(f'''document.getElementById("g-recaptcha-response").innerHTML = "{g_response}"''')
 
     return True if result_flag == None else False
-
-
-def http_remove(link: str):
-    '''url의 http(s) 제거'''
-    link = re.sub("(http|https)\:\/\/",'', link).strip('/')
-    return link
-
-
-def http_append(link: str):
-    '''url에 https 추가'''
-    return link if link.startswith('http') else "https://" + link
-
